@@ -52,22 +52,38 @@ struct StdReplaceIfFunctor {
 
 template <class ExecutionSpace, class IteratorType, class PredicateType,
           class ValueType>
-void replace_if_impl(const std::string& label, const ExecutionSpace& ex,
-                     IteratorType first, IteratorType last, PredicateType pred,
-                     const ValueType& new_value) {
+void replace_if_exespace_impl(const std::string& label,
+                              const ExecutionSpace& ex, IteratorType first,
+                              IteratorType last, PredicateType pred,
+                              const ValueType& new_value) {
   // checks
   Impl::static_assert_random_access_and_accessible(ex, first);
   Impl::expect_valid_range(first, last);
 
-  // aliases
-  using func_t = StdReplaceIfFunctor<IteratorType, PredicateType, ValueType>;
+  // run
+  const auto num_elements = Kokkos::Experimental::distance(first, last);
+  ::Kokkos::parallel_for(
+      label, RangePolicy<ExecutionSpace>(ex, 0, num_elements),
+      StdReplaceIfFunctor(first, std::move(pred), new_value));
+  ex.fence("Kokkos::replace_if: fence after operation");
+}
+
+template <class TeamHandleType, class IteratorType, class PredicateType,
+          class ValueType>
+KOKKOS_FUNCTION void replace_if_team_impl(const TeamHandleType& teamHandle,
+                                          IteratorType first, IteratorType last,
+                                          PredicateType pred,
+                                          const ValueType& new_value) {
+  // checks
+  Impl::static_assert_random_access_and_accessible(teamHandle, first);
+  Impl::expect_valid_range(first, last);
 
   // run
   const auto num_elements = Kokkos::Experimental::distance(first, last);
-  ::Kokkos::parallel_for(label,
-                         RangePolicy<ExecutionSpace>(ex, 0, num_elements),
-                         func_t(first, std::move(pred), new_value));
-  ex.fence("Kokkos::replace_if: fence after operation");
+  ::Kokkos::parallel_for(
+      TeamThreadRange(teamHandle, 0, num_elements),
+      StdReplaceIfFunctor(first, std::move(pred), new_value));
+  teamHandle.team_barrier();
 }
 
 }  // namespace Impl
