@@ -25,8 +25,7 @@
 
 #include <impl/Kokkos_GraphImpl.hpp>  // GraphAccess needs to be complete
 
-#include <Kokkos_Cuda.hpp>
-#include <cuda_runtime_api.h>
+#include <Cuda/Kokkos_Cuda.hpp>
 
 namespace Kokkos {
 namespace Impl {
